You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jena.apache.org by an...@apache.org on 2011/12/01 14:13:09 UTC

svn commit: r1209067 - /incubator/jena/Jena2/ARQ/trunk/src/main/java/com/hp/hpl/jena/query/Query.java

Author: andy
Date: Thu Dec  1 13:13:08 2011
New Revision: 1209067

URL: http://svn.apache.org/viewvc?rev=1209067&view=rev
Log:
Deprecate Query.validate()

Modified:
    incubator/jena/Jena2/ARQ/trunk/src/main/java/com/hp/hpl/jena/query/Query.java

Modified: incubator/jena/Jena2/ARQ/trunk/src/main/java/com/hp/hpl/jena/query/Query.java
URL: http://svn.apache.org/viewvc/incubator/jena/Jena2/ARQ/trunk/src/main/java/com/hp/hpl/jena/query/Query.java?rev=1209067&r1=1209066&r2=1209067&view=diff
==============================================================================
--- incubator/jena/Jena2/ARQ/trunk/src/main/java/com/hp/hpl/jena/query/Query.java (original)
+++ incubator/jena/Jena2/ARQ/trunk/src/main/java/com/hp/hpl/jena/query/Query.java Thu Dec  1 13:13:08 2011
@@ -752,7 +752,11 @@ public class Query extends Prologue impl
     /** Must align with .equals */
     private int hashcode = -1 ;
     
-    /** Perform some check on the query */ 
+    /** Perform some check on the query
+     * @deprecated This call does do anything. 
+     */
+    
+    @Deprecated
     public void validate()
     {
         // This is mostly done now as part of parsing.